Config

Struct Config 

pub struct Config {
    pub providers: ProvidersConfig,
    pub agent: AgentConfig,
    pub computer_control: ComputerControlConfig,
    pub webdriver: WebDriverConfig,
}
Main configuration structure

Fields

providers: ProvidersConfigagent: AgentConfigcomputer_control: ComputerControlConfigwebdriver: WebDriverConfig

Implementations

Source

impl Config

pub fn load(config_path: Option<&str>) -> Result<Self>

pub fn parse_provider_reference(reference: &str) -> Result<(String, String)>

Parse a provider reference into (provider_type, config_name)

pub fn save(&self, path: &str) -> Result<()>

pub fn load_with_overrides( config_path: Option<&str>, provider_override: Option<String>, model_override: Option<String>, ) -> Result<Self>

pub fn get_planner_provider(&self) -> &str

Get the provider reference for planner mode

pub fn get_coach_provider(&self) -> &str

Get the provider reference for coach mode in autonomous execution

pub fn get_player_provider(&self) -> &str

Get the provider reference for player mode in autonomous execution

pub fn with_provider_override(&self, provider_ref: &str) -> Result<Self>

Create a copy of the config with a different default provider

pub fn for_planner(&self) -> Result<Self>

Create a copy of the config for planner mode

pub fn for_coach(&self) -> Result<Self>

Create a copy of the config for coach mode in autonomous execution

pub fn for_player(&self) -> Result<Self>

Create a copy of the config for player mode in autonomous execution

pub fn get_anthropic_config(&self, name: &str) -> Option<&AnthropicConfig>

Get Anthropic config by name

pub fn get_openai_config(&self, name: &str) -> Option<&OpenAIConfig>

Get OpenAI config by name

pub fn get_databricks_config(&self, name: &str) -> Option<&DatabricksConfig>

Get Databricks config by name

pub fn get_embedded_config(&self, name: &str) -> Option<&EmbeddedConfig>

Get Embedded config by name

pub fn get_default_provider_config(&self) -> Result<ProviderConfigRef<'_>>

Get the current default provider’s config